import  { 
  geoPath,
  geoNaturalEarth1,
  zoom,
  event
} from 'd3';

export const choroplethMap = (selection, props) => {
  const { 
    features,
    colorScale,
    colorValue,
    selectedColorValue
  } = props;
  
  const projection = geoNaturalEarth1();
  const pathGenerator = geoPath().projection(projection);
  
  const gUpdate = selection.selectAll("g").data([null]);
  const gEnter = gUpdate.enter().append("g")
  const g = gUpdate.merge(gEnter);
  
  gEnter.append("path")
      .attr("d", pathGenerator({type : "Sphere"}))
      .attr("class", "sphere")
  	.merge(gUpdate.select(".sphere"))
  		.attr("opacity", selectedColorValue ? 0.05 : 1);
  
  selection.call(zoom().on('zoom',() => {
    g.attr('transform', event.transform);
  })); 
  
  const countryPaths = g.selectAll(".country")
  	.data(features);
  
  const countryPathsEnter = countryPaths
    .enter().append("path")
      .attr("class", "country")
      .attr("d", pathGenerator)
  		.attr("fill", d => colorScale(colorValue(d)));
  countryPathsEnter
    .append("title")
      .text(d => d.properties.name + ": " + colorValue(d).slice(3));
  
  countryPaths
    .merge(countryPathsEnter)
    .classed("highlighted", d => selectedColorValue && selectedColorValue === colorValue(d))
      .attr("opacity", d => 
        !selectedColorValue || colorValue(d) === selectedColorValue
        ? 1
        : 0.1
      );
};

