export const colorLegend = (selection, props) => {
  const {
    colorScale,
    circleRadius,
    spacing,
    textOffset,
    backgroundWidth,
    onClick,
    selectedColorValue
  } = props;
  
  const backgroundRect = selection.selectAll('rect')
  	.data([null]);
  const n = colorScale.domain().length;
  backgroundRect.enter().append("rect")
  	.merge(backgroundRect)
  		.attr('x', -circleRadius * 2)
  		.attr('y', -circleRadius * 2)
  		.attr('rx', circleRadius * 2)
  		.attr('width', backgroundWidth)
  		.attr('height', spacing * n + circleRadius * 2)
  		.attr('fill', 'white')
  		.attr('opacity', 0.8)
  
  const groups = selection.selectAll("g")
  	.data(colorScale.domain());
  const groupsEnter = groups.enter().append("g")
  		.attr("class", "tick");
  groupsEnter.merge(groups)
  		.attr("transform", (d, i) => `translate(0, ${i * spacing})`)
  		.attr("opacity", d => 
            !selectedColorValue || d === selectedColorValue
            ? 1
            : 0.1
           )
  		.on("click", d => onClick(d === selectedColorValue ? null : d))
  groups.exit()
  	.remove()
   
  groupsEnter.append("circle")
  	.attr("r", 0)
  	.attr("stroke-width", 0.5)
  	.merge(groups.select("circle"))
  		.attr('fill', colorScale)
  		.attr('r', circleRadius);
    
  groupsEnter.append("text")
  	.merge(groups.select("text"))
  		.attr("x", textOffset)
  		.attr("alignment-baseline", "middle")
  		.text(d => d)
}