import  { 
  select,
  scaleOrdinal,
  schemeSpectral
} from 'd3';
import { loadAndProcessData } from './loadAndProcessData';
import { colorLegend } from './colorLegend';
import { choroplethMap } from './choroplethMap';

const svg = select("svg");
const choroplethMapG = svg.append("g");
const colorLegendG = svg.append("g")
      .attr("transform", `translate(30, 250)`);
const colorScale = scaleOrdinal();
const basis = "economy"
const colorValue = d => d.properties[basis];

// state variables
let selectedColorValue;
let features;

const onClick = d => {
  selectedColorValue = d;
  render();
}
loadAndProcessData()
  .then( countries => {
  	features = countries.features;
  	colorScale
      .domain(features.map(colorValue))
      .domain(colorScale.domain().sort())
      .range(schemeSpectral[colorScale.domain().length].reverse());  
  	render()
	});

const render = () => { 
  colorLegendG.call(colorLegend, { 
      colorScale,
      circleRadius: 7,
      spacing: 20,
      textOffset: 15,
      backgroundWidth: 230,
      onClick,
    	selectedColorValue
    });
  choroplethMapG.call(choroplethMap,{ 
    features,
    colorScale,
    colorValue,
    selectedColorValue
  });
};